@@ -1,12 +1,5 @@
 package CAM::PDF::GS;
 
-use 5.006;
-use strict;
-use warnings;
-use base qw(CAM::PDF::GS::NoText);
-
-our $VERSION = '1.04_01';
-
 =head1 NAME
 
 CAM::PDF::GS - PDF graphic state
@@ -31,24 +24,33 @@ based in the parent class, CAM::PDF::GS::NoText.
 Subclasses that want to do something useful with text should override
 the renderText() method.
 
+=cut
+
+#----------------
+
+use strict;
+use warnings;
+use CAM::PDF::GS::NoText;
+
+use vars qw(@ISA);
+@ISA = qw(CAM::PDF::GS::NoText);
+
+#----------------
+
 =head1 CONVERSION FUNCTIONS
 
-=over
-
-=item $self->getCoords($node)
-
-Computes device coordinates for the specified node.  This implementation
-handles text-printing nodes, and hands all other types to the
-superclass.
+=over 4
 
 =cut
 
+#----------------
+
 sub getCoords
 {
    my $self = shift;
    my $node = shift;
 
-   if ($node->{name} =~ m/ \A (TJ|Tj|quote|doublequote) \z /xms)
+   if ($node->{name} =~ /^(TJ|Tj|quote|doublequote)$/)
    {
       my ($x1,$y1) = $self->userToDevice(@{$self->{last}});
       my ($x2,$y2) = $self->userToDevice(@{$self->{current}});
@@ -60,9 +62,11 @@ sub getCoords
    }
 }
 
-=item $self->textToUser($x, $y)
+#----------------
 
-Convert text coordinates (C<Tm>) to user coordinates.  Returns the
+=item textToUser X, Y
+
+Convert text coordinates (Tm) to user coordinates.  Returns the
 converted X and Y.
 
 =cut
@@ -81,10 +85,11 @@ sub textToUser
    #          0,                        $self->{Ts}];
    #return $self->dot($self->{Tm}, $self->dot($tf, $x, $y));
 }
+#----------------
 
-=item $self->textToDevice($x, $y)
+=item textToDevice X, Y
 
-Convert text coordinates (C<Tm>) to device coordinates.  Returns
+Convert text coordinates (Tm) to device coordinates.  Returns
 the converted X and Y.
 
 =cut
@@ -97,10 +102,11 @@ sub textToDevice
 
    return $self->userToDevice($self->textToUser($x, $y));
 }
+#----------------
 
-=item $self->textLineToUser($x, $y)
+=item textLineToUser X, Y
 
-Convert text coordinates (C<Tlm>) to user coordinates.  Returns
+Convert text coordinates (Tlm) to user coordinates.  Returns
 the converted X and Y.
 
 =cut
@@ -113,10 +119,11 @@ sub textLineToUser
 
    return $self->dot($self->{Tlm}, $x, $y);
 }
+#----------------
 
-=item $self->textLineToDevice($x, $y)
+=item textLineToDevice X, Y
 
-Convert text coordinates (C<Tlm>) to device coordinates.
+Convert text coordinates (Tlm) to device coordinates.
 Returns the converted X and Y.
 
 =cut
@@ -129,10 +136,11 @@ sub textLineToDevice
 
    return $self->userToDevice($self->textLineToUser($x, $y));
 }
+#----------------
 
-=item $self->renderText($string, $width)
+=item renderText STRING, WIDTH
 
-A general method for rendering strings, from C<Tj> or C<TJ>.  This is a
+A general method for rendering strings, from Tj or TJ.  This is a
 no-op, but subclasses may override.
 
 =cut
@@ -144,10 +152,10 @@ sub renderText
    my $width = shift;
 
    # noop, override in subclasses
-   return;
 }
+#----------------
 
-=item $self->Tadvance($width)
+=item Tadvance WIDTH
 
 Move the text cursor.
 
@@ -172,16 +180,20 @@ sub Tadvance
    $self->{moved}->[1] += $ty;
 
    $self->applyMatrix([1,0,0,1,$tx,$ty], $self->{Tm});
-   return;
 }
+#----------------
 
 =back
 
 =head1 DATA FUNCTIONS
 
-=over
+=over 4
 
-=item $self->BT()
+=cut
+
+#----------------
+
+=item BT
 
 =cut
 
@@ -191,10 +203,10 @@ sub BT
   
    @{$self->{Tm}} = (1, 0, 0, 1, 0, 0);
    @{$self->{Tlm}} = (1, 0, 0, 1, 0, 0);
-   return;
 }
+#----------------
 
-=item $self->Tf($fontname, $fontsize)
+=item Tf FONTNAME, FONTSIZE
 
 =cut
 
@@ -210,10 +222,10 @@ sub Tf
 
    # TODO: support vertical text mode (wm = 1)
    $self->{wm} = 0;
-   return;
 }
+#----------------
 
-=item $self->Tstar()
+=item Tstar
 
 =cut
 
@@ -222,10 +234,10 @@ sub Tstar
    my $self = shift;
 
    $self->Td(0, -$self->{TL});
-   return;
 }
+#----------------
 
-=item $self->Tz($scale)
+=item Tz SCALE
 
 =cut
 
@@ -235,10 +247,10 @@ sub Tz
    my $scale = shift;
 
    $self->{Tz} = $scale/100.0;
-   return;
 }
+#----------------
 
-=item $self->Td($x, $y)
+=item Td X, Y
 
 =cut
 
@@ -250,10 +262,10 @@ sub Td
    
    $self->applyMatrix([1,0,0,1,$x,$y], $self->{Tlm});
    @{$self->{Tm}} = @{$self->{Tlm}};
-   return;
 }
+#----------------
 
-=item $self->TD($x, $y)
+=item TD X, Y
 
 =cut
 
@@ -265,10 +277,10 @@ sub TD
 
    $self->TL(-$y);
    $self->Td($x,$y);
-   return;
 }
+#----------------
 
-=item $self->Tj($string)
+=item Tj STRING
 
 =cut
 
@@ -280,7 +292,6 @@ sub Tj
    @{$self->{last}} = $self->textToUser(0,0);
    $self->_Tj($string);
    @{$self->{current}} = $self->textToUser(0,0);
-   return;
 }
 
 sub _Tj
@@ -288,15 +299,12 @@ sub _Tj
    my $self = shift;
    my $string = shift;
 
-   if (!$self->{refs}->{fm})
-   {
-      die "No font metrics for font $self->{Tf}";
-   }
+   die "No font metrics for font $$self{Tf}" unless ($self->{refs}->{fm});
 
    my @parts;
-   if ($self->{mode} eq 'c' || $self->{wm} == 1)
+   if ($self->{mode} eq "c" || $self->{wm} == 1)
    {
-      @parts = split //xms, $string;
+      @parts = split "", $string;
    }
    else
    {
@@ -308,10 +316,10 @@ sub _Tj
       $self->renderText($substr, $dw);
       $self->Tadvance($dw);
    }
-   return;
 }
+#----------------
 
-=item $self->TJ($arrayref)
+=item Tj ARRAYREF
 
 =cut
 
@@ -323,7 +331,7 @@ sub TJ
    @{$self->{last}} = $self->textToUser(0,0);
    foreach my $node (@$array)
    {
-      if ($node->{type} eq 'number')
+      if ($node->{type} eq "number")
       {
          my $dw = -$node->{value} / 1000.0;
          $self->Tadvance($dw);
@@ -334,10 +342,10 @@ sub TJ
       }
    }
    @{$self->{current}} = $self->textToUser(0,0);
-   return;
 }
+#----------------
 
-=item $self->quote($string)
+=item quote
 
 =cut
 
@@ -350,10 +358,10 @@ sub quote
    $self->Tstar();
    $self->_Tj($string);
    @{$self->{current}} = $self->textToUser(0,0);
-   return;
 }
+#----------------
 
-=item $self->doublequote($tw, $tc, $string)
+=item doublequote
 
 =cut
 
@@ -365,10 +373,10 @@ sub doublequote
    my $string = shift;
 
    $self->quote($string);
-   return;
 }
+#----------------
 
-=item $self->Tm($m1, $m2, $m3, $m4, $m5, $m6)
+=item Tm M1, M2, M3, M4, M5, M6
 
 =cut
 
@@ -377,8 +385,8 @@ sub Tm
    my $self = shift;
    
    @{$self->{Tm}} = @{$self->{Tlm}} = @_;
-   return;
 }
+#----------------
 
 1;
 __END__
@@ -388,5 +396,3 @@ __END__
 =head1 AUTHOR
 
 Clotho Advanced Media Inc., I<cpan@clotho.com>
-
-=cut
