@@ -1,18 +1,13 @@
 #!/usr/bin/perl -w
 
-package main;
-
-use warnings;
 use strict;
 use CAM::PDF;
 use Getopt::Long;
 use Pod::Usage;
 
-our $VERSION = '1.04_01';
-
 my %opts = (
             # Hardcoded:
-            template   => 'crunchjpg_tmpl.pdf',
+            template   => "crunchjpg_tmpl.pdf",
 
             # User settable values:
             justjpgs   => 0,
@@ -36,35 +31,25 @@ my %opts = (
             scales     => {1 => undef, 2 => '50%', 4 => '25%', 8 => '12.5%'},
            );
 
-Getopt::Long::Configure('bundling');
-GetOptions('S|skip=s'     => \@{$opts{skipval}},
-           'O|only=s'     => \@{$opts{onlyval}},
-           'q|quality=i'  => \$opts{qualityval},
-           's|scale=i'    => \$opts{scaleval},
-           'm|scalemin=i' => \$opts{scaleminval},
-           'j|justjpgs'   => \$opts{justjpgs},
-           'veryverbose'  => \$opts{Verbose},
-           'v|verbose'    => \$opts{verbose},
-           'o|order'      => \$opts{order},
-           'h|help'       => \$opts{help},
-           'V|version'    => \$opts{version},
+Getopt::Long::Configure("bundling");
+GetOptions("S|skip=s"     => \@{$opts{skipval}},
+           "O|only=s"     => \@{$opts{onlyval}},
+           "q|quality=i"  => \$opts{qualityval},
+           "s|scale=i"    => \$opts{scaleval},
+           "m|scalemin=i" => \$opts{scaleminval},
+           "j|justjpgs"   => \$opts{justjpgs},
+           "veryverbose"  => \$opts{Verbose},
+           "v|verbose"    => \$opts{verbose},
+           "o|order"      => \$opts{order},
+           "h|help"       => \$opts{help},
+           "V|version"    => \$opts{version},
            ) or pod2usage(1);
-if ($opts{help})
-{
-   pod2usage(-exitstatus => 0, -verbose => 2);
-}
-if ($opts{version})
-{
-   print "CAM::PDF v$CAM::PDF::VERSION\n";
-   exit 0;
-}
+pod2usage(-exitstatus => 0, -verbose => 2) if ($opts{help});
+print("CAM::PDF v$CAM::PDF::VERSION\n"),exit(0) if ($opts{version});
 
 ## Fix up and validate special options:
 
-if ($opts{Verbose})
-{
-   $opts{verbose} = 1;
-}
+$opts{verbose} = 1 if ($opts{Verbose});
 if (defined $opts{scaleval})
 {
    if (exists $opts{scales}->{$opts{scaleval}})
@@ -78,7 +63,7 @@ if (defined $opts{scaleval})
 }
 if (defined $opts{scaleminval})
 {
-   if ($opts{scaleminval} =~ m/\A\d+\z/xms && $opts{scaleminval} > 0)
+   if ($opts{scaleminval} =~ /^\d+$/ && $opts{scaleminval} > 0)
    {
       $opts{scalemin} = $opts{scaleminval};
    }
@@ -89,7 +74,7 @@ if (defined $opts{scaleminval})
 }
 if (defined $opts{qualityval})
 {
-   if ($opts{qualityval} =~ m/\A\d+\z/xms && $opts{qualityval} >= 1 && $opts{qualityval} <= 100)
+   if ($opts{qualityval} =~ /^\d+$/ && $opts{qualityval} >= 1 && $opts{qualityval} <= 100)
    {
       $opts{quality} = $opts{qualityval};
    }
@@ -100,9 +85,9 @@ if (defined $opts{qualityval})
 }
 foreach my $flag (qw( skip only ))
 {
-   foreach my $val (@{$opts{$flag.'val'}})
+   foreach my $val (@{$opts{$flag."val"}})
    {
-      foreach my $key (split /\D+/xms, $val)
+      foreach my $key (split /\D+/, $val)
       {
          $opts{$flag}->{$key} = 1;
       }
@@ -121,9 +106,10 @@ if (@ARGV < 1)
 }
 
 my $infile = shift;
-my $outfile = shift || q{-};
+my $outfile = shift || "-";
 
-my $doc = CAM::PDF->new($infile) || die "$CAM::PDF::errstr\n";
+my $doc = CAM::PDF->new($infile);
+die "$CAM::PDF::errstr\n" if (!$doc);
 
 if (!$doc->canModify())
 {
@@ -140,43 +126,34 @@ my $oldcontentsize = $doc->{contentlength};
 my $oldtotsize = 0;
 my $newtotsize = 0;
 
-for my $p (1..$pages)
+for (my $p=1; $p <= $pages; $p++)
 {
    my $c = $doc->getPageContent($p);
-   my @parts = split /(\/[\w]+\s*Do)\b/xms, $c;
+   my @parts = split /(\/[\w]+\s*Do)\b/s, $c;
    foreach my $part (@parts)
    {
-      if ($part =~ m/\A(\/[\w]+)\s*Do\z/xms)
+      if ($part =~ /^(\/[\w]+)\s*Do$/s)
       {
          my $ref = $1;
          my $xobj = $doc->dereference($ref, $p);
          my $objnum = $xobj->{objnum};
          my $im = $doc->getValue($xobj);
          my $l = $im->{Length} || $im->{L} || 0;
-         if ($l)
-         {
-            $l = $doc->getValue($l);
-         }
+         $l = $doc->getValue($l) if ($l);
          my $w = $im->{Width} || $im->{W} || 0;
-         if ($w)
-         {
-            $w = $doc->getValue($w);
-         }
+         $w = $doc->getValue($w) if ($w);
          my $h = $im->{Height} || $im->{H} || 0;
-         if ($h)
-         {
-            $h = $doc->getValue($h);
-         }
+         $h = $doc->getValue($h) if ($h);
 
          next if (exists $doneobjs{$objnum});
 
          $nimages++;
-         _inform("Image $nimages page $p, $ref = object $objnum, (w,h)=($w,$h), length $l", $opts{verbose});
+         print STDERR "Image $nimages page $p, $ref = object $objnum, (w,h)=($w,$h), length $l\n" if ($opts{verbose});
 
          if (exists $opts{skip}->{$objnum} ||
-             (0 < scalar keys %{$opts{only}} && !exists $opts{only}->{$objnum}))
+             (scalar (keys %{$opts{only}}) > 0 && (!exists $opts{only}->{$objnum})))
          {
-            _inform("Skipping object $objnum", $opts{verbose});
+            print STDERR "Skipping object $objnum\n" if ($opts{verbose});
             next;
          }
 
@@ -184,17 +161,14 @@ for my $p (1..$pages)
          if ($im->{Filter})
          {
             my $f = $im->{Filter};
-            if ($f->{type} eq 'array')
+            if ($f->{type} eq "array")
             {
                foreach my $e (@{$f->{value}})
                {
                   my $name = $doc->getValue($e);
-                  if (ref $name)
-                  {
-                     $name = $name->{value};
-                  }
+                  $name = $name->{value} if (ref $name);
                   #warn "Checking $name\n";
-                  if ($name eq 'DCTDecode')
+                  if ($name eq "DCTDecode")
                   {
                      $isjpg = 1;
                      last;
@@ -204,12 +178,9 @@ for my $p (1..$pages)
             else
             {
                my $name = $doc->getValue($f);
-               if (ref $name)
-               {
-                  $name = $name->{value};
-               }
+               $name = $name->{value} if (ref $name);
                #warn "Checking $name\n";
-               if ($name eq 'DCTDecode')
+               if ($name eq "DCTDecode")
                {
                   $isjpg = 1;
                }
@@ -218,7 +189,7 @@ for my $p (1..$pages)
 
          if ((!$isjpg) && $opts{justjpgs})
          {
-            _inform('Not a jpeg', $opts{verbose});
+            print STDERR "Not a jpeg\n" if ($opts{verbose});
          }
          else
          {
@@ -229,7 +200,8 @@ for my $p (1..$pages)
             }
             $oldtotsize += $oldsize;
 
-            my $tmpl = CAM::PDF->new($opts{template}) || die "$CAM::PDF::errstr\n";
+            my $tmpl = CAM::PDF->new($opts{template});
+            die "$CAM::PDF::errstr\n" if (!$tmpl);
             
             # Get a handle on the needed data bits from the template
             my $media_array = $tmpl->getValue($tmpl->getPage(1)->{MediaBox});
@@ -238,33 +210,34 @@ for my $p (1..$pages)
             $media_array->[2]->{value} = $w;
             $media_array->[3]->{value} = $h;
             my $page = $rawpage;
-            $page =~ s/xxx/$w/igxms;
-            $page =~ s/yyy/$h/igxms;
+            $page =~ s/xxx/$w/ig;
+            $page =~ s/yyy/$h/ig;
             $tmpl->setPageContent(1, $page);
             $tmpl->replaceObject(9, $doc, $objnum, 1);
 
             my $ofile = "/tmp/crunchjpg.$$";
             $tmpl->cleanoutput($ofile);
 
-            my $cmd = ('convert ' . 
+            local *PIPE;
+            my $cmd = ("convert " . 
                        ($opts{scale} && $w > $opts{scalemin} && $h > $opts{scalemin} ?
-                        "-scale '$opts{scale}' " : q{}) . 
+                        "-scale '$opts{scale}' " : "") . 
                        "-quality $opts{quality} " .
-                       '-density 72x72 ' .
+                       "-density 72x72 " .
                        "-page ${w}x$h " .
                        "pdf:$ofile jpg:- | " .
-                       'convert jpg:- pdf:- |');
+                       "convert jpg:- pdf:- |");
 
-            _inform($cmd, $opts{Verbose});
+            print STDERR "$cmd\n" if ($opts{Verbose});
 
-            # TODO: this should use IPC::Open3 or the like
-            open my $pipe, $cmd  ## no critic
+            open(PIPE, $cmd)
                 or die "Failed to convert object $objnum to a jpg and back\n";
-            my $content = join q{}, <$pipe>;
-            close $pipe 
+            my $content = join('', <PIPE>);
+            close(PIPE) 
                 or die "Failed to convert object $objnum to a jpg and back\n";
 
-            my $jpg = CAM::PDF->new($content) || die "$CAM::PDF::errstr\n";
+            my $jpg = CAM::PDF->new($content);
+            die "$CAM::PDF::errstr\n" if (!$jpg);
 
             $doc->replaceObject($objnum, $jpg, 9, 1);
 
@@ -272,8 +245,7 @@ for my $p (1..$pages)
             my $newsize = $doc->getValue($newim->{Length});
             $newtotsize += $newsize;
 
-            my $percent = sprintf '%.1f', 100 * ($oldsize - $newsize) / $oldsize;
-            _inform("compressed $oldsize -> $newsize ($percent%)", $opts{verbose});
+            print STDERR "compressed $oldsize -> $newsize (" . sprintf("%.1f",100*($oldsize-$newsize)/$oldsize) . "%)\n" if ($opts{verbose});
 
             $doneobjs{$objnum} = 1;
             $rimages++;
@@ -282,44 +254,32 @@ for my $p (1..$pages)
    }
 }
 
-_inform("Crunched $rimages of $nimages images", $opts{verbose});
+print STDERR "Crunched $rimages of $nimages images\n" if ($opts{verbose});
 $doc->cleanoutput($outfile);
 
 my $newcontentsize = $doc->{contentlength};
 
 if ($opts{verbose})
 {
-   my $contentpercent = sprintf '%.1f', $oldcontentsize ? 100 * ($oldcontentsize - $newcontentsize) / $oldcontentsize : 0;
-   my $totpercent = sprintf '%.1f', $oldtotsize ? 100 * ($oldtotsize - $newtotsize) / $oldtotsize : 0;
-   _inform('Compression summary:', 1);
-   _inform("  Document: $oldcontentsize -> $newcontentsize ($contentpercent%)", 1);
-   _inform("  Images: $oldtotsize -> $newtotsize ($totpercent%)", 1);
+   print STDERR "Compression summary:\n";
+   print STDERR "  Document: $oldcontentsize -> $newcontentsize (" . 
+       sprintf("%.1f", ($oldcontentsize ? 100*($oldcontentsize-$newcontentsize)/$oldcontentsize : 0)) . 
+           "%)\n";
+   print STDERR "  Images: $oldtotsize -> $newtotsize (" . 
+       sprintf("%.1f", ($oldtotsize ? 100*($oldtotsize-$newtotsize)/$oldtotsize : 0)) . 
+           "%)\n";
 }
 
 
-sub _inform
-{
-   my $str     = shift;
-   my $verbose = shift;
-
-   if ($verbose)
-   {
-      print STDERR $str, "\n";
-   }
-   return;
-}
-
 __END__
 
-=for stopwords crunchjpgs.pl ImageMagick JPG
-
 =head1 NAME
 
 crunchjpgs.pl - Compress all JPG images in a PDF
 
 =head1 SYNOPSIS
 
- crunchjpgs.pl [options] infile.pdf [outfile.pdf]
+crunchjpgs.pl [options] infile.pdf [outfile.pdf]
 
  Options:
    -j --justjpgs       make script skip non-JPGs
@@ -342,12 +302,12 @@ The available values for --scale are:
     8   12.5%
 
 C<imnum> is a comma-separated list of integers indicating the images
-in order that they appear in the PDF.  Use F<listimages.pl> to retrieve
+in order that they appear in the PDF.  Use listimages.pl to retrieve
 the image numbers.
 
 =head1 DESCRIPTION
 
-Requires the ImageMagick B<convert> program to be available
+Requires the ImageMagick C<convert> program to be available
 
 Tweak all of the JPG images embedded in a PDF to reduce their size.
 This reduction can come from increasing the compression and/or
@@ -358,16 +318,14 @@ which images are altered.
 
 CAM::PDF
 
-F<listimages.pl>
+listimages.pl
 
-F<extractallimages.pl>
+extractallimages.pl
 
-F<extractjpgs.pl>
+extractjpgs.pl
 
-F<uninlinepdfimages.pl>
+uninlinepdfimages.pl
 
 =head1 AUTHOR
 
 Clotho Advanced Media Inc., I<cpan@clotho.com>
-
-=cut
