@@ -1,16 +1,11 @@
 #!/usr/bin/perl -w
 
-package main;
-
-use warnings;
 use strict;
 use CAM::PDF;
 use Data::Dumper;
 use Getopt::Long;
 use Pod::Usage;
 
-our $VERSION = '1.04_01';
-
 my %opts = (
             decode     => 0,
             content    => 0,
@@ -19,22 +14,15 @@ my %opts = (
             version    => 0,
             );
 
-Getopt::Long::Configure('bundling');
-GetOptions('d|decode'   => \$opts{decode},
-           'c|content'  => \$opts{content},
-           'v|verbose'  => \$opts{verbose},
-           'h|help'     => \$opts{help},
-           'V|version'  => \$opts{version},
+Getopt::Long::Configure("bundling");
+GetOptions("d|decode"   => \$opts{decode},
+           "c|content"  => \$opts{content},
+           "v|verbose"  => \$opts{verbose},
+           "h|help"     => \$opts{help},
+           "V|version"  => \$opts{version},
            ) or pod2usage(1);
-if ($opts{help})
-{
-   pod2usage(-exitstatus => 0, -verbose => 2);
-}
-if ($opts{version})
-{
-   print "CAM::PDF v$CAM::PDF::VERSION\n";
-   exit 0;
-}
+pod2usage(-exitstatus => 0, -verbose => 2) if ($opts{help});
+print("CAM::PDF v$CAM::PDF::VERSION\n"),exit(0) if ($opts{version});
 
 if (@ARGV < 2)
 {
@@ -44,12 +32,13 @@ if (@ARGV < 2)
 my $file = shift;
 my $pagenum = shift;
 
-if ($pagenum !~ m/\A\d+\z/xms || $pagenum < 1)
+if ($pagenum !~ /^\d+$/ || $pagenum < 1)
 {
    die "The page number must be an integer greater than 0\n";
 }
 
-my $doc = CAM::PDF->new($file) || die "$CAM::PDF::errstr\n";
+my $doc = CAM::PDF->new($file);
+die "$CAM::PDF::errstr\n" if (!$doc);
 
 my $page = $doc->getPage($pagenum);
 
@@ -62,28 +51,23 @@ if ($opts{content})
    $page = $doc->getValue($page->{Contents});
 }
 
-if ($opts{decode})
-{
-   $doc->decodeAll(CAM::PDF::Node->new('dictionary', $page));
-}
+$doc->decodeAll(CAM::PDF::Node->new("dictionary",$page)) if ($opts{decode});
 
 if ($opts{verbose})
 {
-   print Data::Dumper->Dump([$page], ['page']);
+   print Data::Dumper->Dump([$page], ["page"]);
 }
 
 
 __END__
 
-=for stopwords getpdfpageobject.pl
-
 =head1 NAME
 
 getpdfpageobject.pl - Print the PDF page metadata
 
 =head1 SYNOPSIS
 
- getpdfpageobject.pl [options] infile.pdf pagenum
+getpdfpageobject.pl [options] infile.pdf pagenum
 
  Options:
    -d --decode         uncompress any elements
@@ -94,7 +78,7 @@ getpdfpageobject.pl - Print the PDF page metadata
 
 =head1 DESCRIPTION
 
-Retrieves the page metadata from the PDF.  If C<--verbose> is specified,
+Retrieves the page metadata from the PDF.  If --verbose is specified,
 the memory representation is dumped to STDOUT.  Otherwise, the program
 silently returns success or emits a failure message to STDERR.
 
@@ -102,12 +86,10 @@ silently returns success or emits a failure message to STDERR.
 
 CAM::PDF
 
-F<getpdfpage.pl>
+getpdfpage.pl
 
-F<setpdfpage.pl>
+setpdfpage.pl
 
 =head1 AUTHOR
 
 Clotho Advanced Media Inc., I<cpan@clotho.com>
-
-=cut
