@@ -1,15 +1,10 @@
 #!/usr/bin/perl -w
 
-package main;
-
-use warnings;
 use strict;
 use CAM::PDF;
 use Getopt::Long;
 use Pod::Usage;
 
-our $VERSION = '1.04_01';
-
 my %opts = (
             sort       => 0,
             verbose    => 0,
@@ -17,21 +12,14 @@ my %opts = (
             version    => 0,
             );
 
-Getopt::Long::Configure('bundling');
-GetOptions('s|sort'     => \$opts{sort},
-           'v|verbose'  => \$opts{verbose},
-           'h|help'     => \$opts{help},
-           'V|version'  => \$opts{version},
+Getopt::Long::Configure("bundling");
+GetOptions("s|sort"     => \$opts{sort},
+           "v|verbose"  => \$opts{verbose},
+           "h|help"     => \$opts{help},
+           "V|version"  => \$opts{version},
            ) or pod2usage(1);
-if ($opts{help})
-{
-   pod2usage(-exitstatus => 0, -verbose => 2);
-}
-if ($opts{version})
-{
-   print "CAM::PDF v$CAM::PDF::VERSION\n";
-   exit 0;
-}
+pod2usage(-exitstatus => 0, -verbose => 2) if ($opts{help});
+print("CAM::PDF v$CAM::PDF::VERSION\n"),exit(0) if ($opts{version});
 
 if (@ARGV < 1)
 {
@@ -40,30 +28,26 @@ if (@ARGV < 1)
 
 my $infile = shift;
 
-my $doc = CAM::PDF->new($infile) || die "$CAM::PDF::errstr\n";
+my $doc = CAM::PDF->new($infile);
+die "$CAM::PDF::errstr\n" if (!$doc);
 
 my @list = $doc->getFormFieldList();
-if ($opts{sort})
-{
-   @list = sort @list;
-}
+@list = sort @list if ($opts{sort});
 foreach my $name (@list)
 {
-   print $name, "\n";
+   print "$name\n";
 }
 
 
 __END__
 
-=for stopwords listpdffields.pl
-
 =head1 NAME
 
 listpdffields.pl - Print the PDF form field names
 
 =head1 SYNOPSIS
 
- listpdffields.pl [options] infile.pdf
+listpdffields.pl [options] infile.pdf
 
  Options:
    -s --sort           sort the output list alphabetically
@@ -79,10 +63,8 @@ Outputs to STDOUT all of the field names for any forms in the PDF document.
 
 CAM::PDF
 
-F<fillpdffields.pl>
+fillpdffields.pl
 
 =head1 AUTHOR
 
 Clotho Advanced Media Inc., I<cpan@clotho.com>
-
-=cut
