@@ -1,14 +1,9 @@
 #!/usr/bin/perl -w
 
-package main;
-
-use warnings;
 use strict;
 use Getopt::Long;
 use Pod::Usage;
 
-our $VERSION = '1.04_01';
-
 my %opts = (
             count      => 0,
             verbose    => 0,
@@ -16,22 +11,14 @@ my %opts = (
             version    => 0,
             );
 
-Getopt::Long::Configure('bundling');
-GetOptions('c|count'      => \$opts{count},
-           'v|verbose'    => \$opts{verbose},
-           'h|help'       => \$opts{help},
-           'V|version'    => \$opts{version},
+Getopt::Long::Configure("bundling");
+GetOptions("c|count"      => \$opts{count},
+           "v|verbose"    => \$opts{verbose},
+           "h|help"       => \$opts{help},
+           "V|version"    => \$opts{version},
            ) or pod2usage(1);
-if ($opts{help})
-{
-   pod2usage(-exitstatus => 0, -verbose => 2);
-}
-if ($opts{version})
-{
-   require CAM::PDF;
-   print "CAM::PDF v$CAM::PDF::VERSION\n";
-   exit 0;
-}
+pod2usage(-exitstatus => 0, -verbose => 2) if ($opts{help});
+require("CAM::PDF"),print("CAM::PDF v$CAM::PDF::VERSION\n"),exit(0) if ($opts{version});
 
 if (@ARGV < 1)
 {
@@ -39,14 +26,16 @@ if (@ARGV < 1)
 }
 
 my $infile = shift;
-my $outfile = shift || q{-};
+my $outfile = shift || "-";
 
-open my $in_fh, '<', $infile
-    or die "Failed to read file $infile\n";
-my $content = join q{}, <$in_fh>;
-close $in_fh;
+local *IN;
+local *OUT;
 
-my @matches = ($content =~ m/ [\r\n]%%EOF *[\r\n] /gxms);
+open(IN, $infile) or die "Failed to read file $infile\n";
+my $content = join("", <IN>);
+close(IN);
+
+my @matches = ($content =~ /[\r\n]%%EOF *[\r\n]/sg);
 my $revs = @matches;
 
 if ($opts{count})
@@ -63,40 +52,35 @@ elsif ($revs == 1)
 }
 else
 {
-   # Figure out line end character
-   $content =~ m/ (.)%%EOF.*?\z /xms
-       or die "Cannot find the end-of-file marker\n";
-   my $lineend = $1;
-   my $eof = $lineend.'%%EOF';
-
-   my $i = rindex $content, $eof;
-   my $j = rindex $content, $eof, $i-1;
-   $content = (substr $content, 0, $j) . $eof . $lineend;
-
-   if ($outfile eq q{-})
+   if ($outfile eq "-")
    {
-      print STDOUT $content;
+      *OUT = *STDOUT;
    }
    else
    {
-      open my $fh, '>', $outfile or die "Cannot write to $outfile\n";
-      print {$fh} $content;
-      close $fh;
+      open(OUT, ">$outfile") or die "Cannot write to $outfile\n";
    }
+
+   # Figure out line end character
+   $content =~ /(.)%%EOF.*?$/s;
+   my $lineend = $1;
+   
+   my $i = rindex($content, "$lineend%%EOF");
+   my $j = rindex($content, "$lineend%%EOF", $i-1);
+   print OUT substr($content, 0, $j);
+   print OUT $lineend . "%%EOF" . $lineend;
 }
 
 
 __END__
 
-=for stopwords revertpdf.pl
-
 =head1 NAME
 
 revertpdf.pl - Remove the last edits to a PDF document
 
 =head1 SYNOPSIS
 
- revertpdf.pl [options] infile.pdf [outfile.pdf]\n";
+revertpdf.pl [options] infile.pdf [outfile.pdf]\n";
 
  Options:
    -c --count          just print the number of revisions and exits
@@ -115,7 +99,7 @@ version of the PDF.
 This program remove the last layer of edits from the PDF document.  If
 there is just one revision, we emit a message and abort.
 
-The C<--count> option just prints the number of generations the document
+The --count option just prints the number of generations the document
 has endured and applies no changes.
 
 =head1 SEE ALSO
@@ -125,5 +109,3 @@ CAM::PDF
 =head1 AUTHOR
 
 Clotho Advanced Media Inc., I<cpan@clotho.com>
-
-=cut
